0.9.9 API documentation: matrix_major_storage.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

matrix_major_storage.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../glm.hpp"
18
19 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
20 # ifndef GLM_ENABLE_EXPERIMENTAL
21 # pragma message("GLM: GLM_GTX_matrix_major_storage is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
22 # else
23 # pragma message("GLM: GLM_GTX_matrix_major_storage extension included")
24 # endif
25 #endif
26
27 namespace glm
28 {
31
34 template<typename T, qualifier Q>
35 GLM_FUNC_DECL mat<2, 2, T, Q> rowMajor2(
36 vec<2, T, Q> const& v1,
37 vec<2, T, Q> const& v2);
38
41 template<typename T, qualifier Q>
42 GLM_FUNC_DECL mat<2, 2, T, Q> rowMajor2(
43 mat<2, 2, T, Q> const& m);
44
47 template<typename T, qualifier Q>
48 GLM_FUNC_DECL mat<3, 3, T, Q> rowMajor3(
49 vec<3, T, Q> const& v1,
50 vec<3, T, Q> const& v2,
51 vec<3, T, Q> const& v3);
52
55 template<typename T, qualifier Q>
56 GLM_FUNC_DECL mat<3, 3, T, Q> rowMajor3(
57 mat<3, 3, T, Q> const& m);
58
61 template<typename T, qualifier Q>
62 GLM_FUNC_DECL mat<4, 4, T, Q> rowMajor4(
63 vec<4, T, Q> const& v1,
64 vec<4, T, Q> const& v2,
65 vec<4, T, Q> const& v3,
66 vec<4, T, Q> const& v4);
67
70 template<typename T, qualifier Q>
71 GLM_FUNC_DECL mat<4, 4, T, Q> rowMajor4(
72 mat<4, 4, T, Q> const& m);
73
76 template<typename T, qualifier Q>
77 GLM_FUNC_DECL mat<2, 2, T, Q> colMajor2(
78 vec<2, T, Q> const& v1,
79 vec<2, T, Q> const& v2);
80
83 template<typename T, qualifier Q>
84 GLM_FUNC_DECL mat<2, 2, T, Q> colMajor2(
85 mat<2, 2, T, Q> const& m);
86
89 template<typename T, qualifier Q>
90 GLM_FUNC_DECL mat<3, 3, T, Q> colMajor3(
91 vec<3, T, Q> const& v1,
92 vec<3, T, Q> const& v2,
93 vec<3, T, Q> const& v3);
94
97 template<typename T, qualifier Q>
98 GLM_FUNC_DECL mat<3, 3, T, Q> colMajor3(
99 mat<3, 3, T, Q> const& m);
100
103 template<typename T, qualifier Q>
104 GLM_FUNC_DECL mat<4, 4, T, Q> colMajor4(
105 vec<4, T, Q> const& v1,
106 vec<4, T, Q> const& v2,
107 vec<4, T, Q> const& v3,
108 vec<4, T, Q> const& v4);
109
112 template<typename T, qualifier Q>
113 GLM_FUNC_DECL mat<4, 4, T, Q> colMajor4(
114 mat<4, 4, T, Q> const& m);
115
117 }//namespace glm
118
119 #include "matrix_major_storage.inl"
glm::rowMajor4
GLM_FUNC_DECL mat< 4, 4, T, Q > rowMajor4(mat< 4, 4, T, Q > const &m)
Build a row major matrix from other matrix.
glm::rowMajor2
GLM_FUNC_DECL mat< 2, 2, T, Q > rowMajor2(mat< 2, 2, T, Q > const &m)
Build a row major matrix from other matrix.
glm::colMajor4
GLM_FUNC_DECL mat< 4, 4, T, Q > colMajor4(mat< 4, 4, T, Q > const &m)
Build a column major matrix from other matrix.
glm::colMajor3
GLM_FUNC_DECL mat< 3, 3, T, Q > colMajor3(mat< 3, 3, T, Q > const &m)
Build a column major matrix from other matrix.
glm::colMajor2
GLM_FUNC_DECL mat< 2, 2, T, Q > colMajor2(mat< 2, 2, T, Q > const &m)
Build a column major matrix from other matrix.
glm::rowMajor3
GLM_FUNC_DECL mat< 3, 3, T, Q > rowMajor3(mat< 3, 3, T, Q > const &m)
Build a row major matrix from other matrix.
glm
Definition: common.hpp:20